@@ -20,7 +20,7 @@ Perlanet::Trait::Cache - cache feeds with CHI
 
 =head1 DESCRIPTION
 
-Everytime a page is fetched it is cached first through CHI. This allows you
+Every time a page is fetched it is cached first through CHI. This allows you
 to cache pages to a local disk for example, if the feed has not changed.
 
 =head1 ATTRIBUTES
@@ -49,7 +49,7 @@ around 'fetch_page' => sub {
 
 =head1 AUTHOR
 
-Dave Cross, <dave@mag-sol.com>
+Dave Cross, <dave@perlhacks.com>
 
 =head1 COPYRIGHT AND LICENSE
 
