@@ -79,7 +79,7 @@ has 'opml_file' => (
 
 =head2 update_opml
 
-Updates the OPML file of all contributers to this planet. If the L<opml_file>
+Updates the OPML file of all contributors to this planet. If the L<opml_file>
 attribute does not have a value, this method does nothing, otherwise it inserts
 each author into the OPML file and saves it to disk.
 
@@ -89,9 +89,10 @@ sub update_opml {
   my $self = shift;
   my ($feeds) = @_;
 
-  return unless $self->has_opml;
-
   foreach my $f (@$feeds) {
+
+    return unless $self->opml_file and $self->has_opml;
+
     $self->opml_generator->insert_outline(
       title   => $f->title,
       text    => $f->title,
@@ -125,7 +126,7 @@ around 'fetch_feeds' => sub {
 
 =head1 AUTHOR
 
-Dave Cross, <dave@mag-sol.com>
+Dave Cross, <dave@perlhacks.com>
 
 =head1 COPYRIGHT AND LICENSE
 
